==> kadu_0.11.2.orig.tar.bz2: kadu-0.11.2/plugins/last_seen/translations/last_seen_tr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="tr">
<context>
    <name>Infos</name>
    <message>
        <source>&amp;Show infos about buddies...</source>
        <translation>Arkadaşların bilgilerini &amp;gösterir...</translation>
    </message>
</context>
<context>
    <name>InfosDialog</name>
    <message>
        <source>Buddies Information</source>
        <translation>Arkadaşların Bilgileri</translation>
    </message>
    <message>
        <source>Buddy</source>
        <translation>Arkadaş</translation>
    </message>
    <message>
        <source>Protocol</source>
        <translation>Protokol</translation>
    </message>
    <message>
        <source>UIN</source>
        <translation>UIN</translation>
    </message>
    <message>
        <source>Nick</source>
        <translation>Takma İsim</translation>
    </message>
    <message>
        <source>IP</source>
        <translation>IP</translation>
    </message>
    <message>
        <source>Domain name</source>
        <translation>Domain Adı</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Tanım</translation>
    </message>
    <message>
        <source>State</source>
        <translation>Ülke</translation>
    </message>
    <message>
        <source>Last time seen on</source>
        <translation>En son görüldüğü zaman</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Kapat</translation>
    </message>
</context>
</TS>

==> kadu_0.12.3.orig.tar.bz2: kadu-0.12.3/plugins/last_seen/translations/last_seen_tr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="tr">
<context>
    <name>Infos</name>
    <message>
        <source>&amp;Show infos about buddies...</source>
        <translation>Arkadaşların bilgilerini &amp;gösterir...</translation>
    </message>
</context>
<context>
    <name>InfosDialog</name>
    <message>
        <source>Buddies Information</source>
        <translation>Arkadaşların Bilgileri</translation>
    </message>
    <message>
        <source>Buddy</source>
        <translation>Arkadaş</translation>
    </message>
    <message>
        <source>Protocol</source>
        <translation>Protokol</translation>
    </message>
    <message>
        <source>Nick</source>
        <translation>Takma İsim</translation>
    </message>
    <message>
        <source>IP</source>
        <translation>IP</translation>
    </message>
    <message>
        <source>Domain name</source>
        <translation>Domain Adı</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Tanım</translation>
    </message>
    <message>
        <source>State</source>
        <translation>Ülke</translation>
    </message>
    <message>
        <source>Last time seen on</source>
        <translation>En son görüldüğü zaman</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Kapat</translation>
    </message>
    <message>
        <source>Username</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
